//                                               -*- C++ -*-
/**
 * @file    NearestPointAlgorithmProperty.hxx
 * @brief
 *
 * @author  Romuald Conty
 * @date    2007-01-14 11:34:14
 *
 * @par Last change :
 *  $LastChangedBy: dutka $
 *  $LastChangedDate: 2008-06-26 13:50:17 +0200 (jeu 26 jun 2008) $
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */
#ifndef OPENTURNS_UI_GUIOPTIMIZATIONMETHODPROPERTY_HXX
#define OPENTURNS_UI_GUIOPTIMIZATIONMETHODPROPERTY_HXX

// OT::UI::GUI
#include "QOTProperty.hxx"

// OT
#include "NearestPointAlgorithm.hxx"
#include "AbdoRackwitz.hxx"
#include "Cobyla.hxx"


namespace OpenTURNS
{

	namespace UI
	{

		namespace GUI
		{

			class NearestPointAlgorithmProperty : public QOTProperty
			{
					Q_OBJECT

					typedef OT::Base::Optimisation::NearestPointAlgorithm NearestPointAlgorithm;

					typedef OT::Base::Optimisation::Cobyla Cobyla;
					typedef OT::Base::Optimisation::AbdoRackwitz AbdoRackwitz;

				public:
					NearestPointAlgorithmProperty ( NearestPointAlgorithm* nearestPointAlgorithm, QObject* parent, const char* name );

					~NearestPointAlgorithmProperty();

					virtual QString getValue();
					virtual QStringList getChoices();
					virtual bool setValue ( QString value );

				public slots:
					void generateNearestPointAlgorithm();

				protected:
					void autoconnect ( QOTProperty* property );

				protected:
					NearestPointAlgorithm* nearestPointAlgorithm_;

					QString method_;
					NumericalScalar maxAbsoluteError_;
					NumericalScalar maxConstraintError_;
					NumericalScalar maxRelativeError_;
					NumericalScalar maxResidualError_;
					UnsignedLong maxIterationsNumber_;

			};

		}

	}

}

#endif
