//                                               -*- C++ -*-
/**
 * @file    StepC3.cxx
 * @brief
 *
 * @author  Romuald Conty
 * @date    2006-08-31 12:50:47
 *
 * @par Last change :
 *  $LastChangedBy: dutka $
 *  $LastChangedDate: 2007-11-08 17:13:40 +0100 (jeu 08 nov 2007) $
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */
//Header
#include "StepC3.hxx"

// OT::UI::GUI
#include "QOTAction.hxx"
#include "Study.hxx"
#include "ThresholdExceedance.hxx"
#include "BlockC3.hxx"

// Qt
#include <qobjectlist.h>
#include <qmessagebox.h>

namespace OpenTURNS
{
	namespace UI
	{
		namespace GUI
		{
			StepC3::StepC3 ( QOTObject* parent, Study * study ) : Step ( parent, "Step C3" )
			{
				setName ( tr ( "Step C3" ) );
				setDescription ( tr ( "C3: Threshold exceedance" ) );

				/* "Block creation" */
				const QString title = tr ( "&New Block C3" ) + "...";
				connect ( new QOTAction ( title, 0, this, "StepC3_newBlock" ), SIGNAL ( activated() ) , this, SLOT ( createBlock() ) );

				study_ = study;
				setRenameEnabled ( false );
			}

			StepC3::~StepC3()
			{}

			QString StepC3::getFullName() const
			{
				return getDescription();
			}

			void StepC3::createBlock()
			{
				QObjectList * blockBList = new QObjectList();
				study_->getStepB() ->getChildren ( blockBList, "OpenTURNS::UI::GUI::BlockB", true, false );

				const QString title = tr ( "Create Block" ) + " - OpenTURNS";
				QString blockName = giveUniqueChildName ( "BlockC3_1" );
				QString calculationName = giveUniqueChildName ( "CalculationC3_1" );
				QString msg = "";

				if ( blockBList->count() > 0 )
				{
					// there is at least one block B
					BlockB * blockB = NULL;
					if ( blockBList->count() == 1 )
					{
						blockB = ( BlockB* ) blockBList->at ( 0 );
					}
					else
					{
						blockB = ( BlockB* ) chooseQOTObject ( title, tr ( "Choose a block B" ), blockBList );
					}

					if ( blockB != NULL )
					{
						QObjectList * thresholdExceedanceList = new QObjectList();
						blockB->getBlockA_ptr() ->getChildren ( thresholdExceedanceList, "OpenTURNS::UI::GUI::ThresholdExceedance", true, false );

						if ( thresholdExceedanceList->count() > 0 )
						{
							// there is at least one threshold exceedance

							ThresholdExceedance * thresholdExceedance = NULL;
							if ( thresholdExceedanceList->count() == 1 )
							{
								thresholdExceedance = ( ThresholdExceedance* ) thresholdExceedanceList->at ( 0 );
							}
							else
							{
								thresholdExceedance = ( ThresholdExceedance* ) chooseQOTObject ( title, tr ( "Choose a threshold exceedance" ), thresholdExceedanceList );
							}

							if ( thresholdExceedance != NULL )
							{
								QObjectList * finalVariableList = new QObjectList();
								blockB->getBlockA_ptr() ->getChildren ( finalVariableList, "OpenTURNS::UI::GUI::FinalVariable", true, false );

								if ( finalVariableList->count() > 0 )
								{
									FinalVariable * finalVariable = NULL;
									if ( finalVariableList->count() == 1 )
									{
										finalVariable = ( FinalVariable* ) finalVariableList->at ( 0 );
									}
									else
									{
										finalVariable = ( FinalVariable* ) chooseQOTObject ( title, tr ( "Choose a final variable" ), finalVariableList );
									}

									if ( finalVariable != NULL )
									{
										BlockC3 * blockC3 = new BlockC3 ( this, blockName );
										blockC3->setBlockB_ptr ( blockB );
										blockC3->setThresholdExceedance_ptr ( thresholdExceedance );
										blockC3->setFinalVariable_ptr ( finalVariable );

										new CalculationC3 ( blockC3, calculationName );
										listBlocks_.append ( blockC3 );
										emit updated();
									}
								}
								else
								{
									msg = tr ( "You must create at least one final variable." );
									QMessageBox::warning ( NULL, title, msg, QMessageBox::Ok, QMessageBox::NoButton );
								}
							}

						}
						else
						{
							msg = tr ( "You must create at least one threshold exceedance." );
							QMessageBox::warning ( NULL, title, msg, QMessageBox::Ok, QMessageBox::NoButton );
						}
					}

				}
				else
				{
					msg = tr ( "You must create at least one block in step B." );
					QMessageBox::warning ( NULL, title, msg, QMessageBox::Ok, QMessageBox::NoButton );
				}
			}
		} /* namespace GUI */
	} /* namespace UI */
} /* namespace OpenTURNS */

