//                                               -*- C++ -*-
/**
 *  @file  Compact.cxx
 *  @brief 
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $CompactChangedBy$
 *  @date:   $CompactChangedDate$
 *  Id:      $Id: Compact.cxx 995 2008-10-31 10:52:04Z dutka $
 */
#include "Compact.hxx"

namespace OpenTURNS
{

  namespace Base 
  {

    namespace Stat
    {

      /**
       * @class Compact
       */

      CLASSNAMEINIT(Compact);

      const UnsignedLong Compact::DefaultHalfMaximumSize;

      /* Constructor with parameters */
      Compact::Compact()
	: HistoryStrategyImplementation(),
	  halfMaximumSize_(DefaultHalfMaximumSize),
	  index_(0),
	  step_(1),
	  throwingCounter_(0)
      {
	// Nothing to do
      }

      /* Constructor with parameters */
      Compact::Compact(const UnsignedLong halfMaximumSize)
	: HistoryStrategyImplementation(),
	  halfMaximumSize_(halfMaximumSize),
	  index_(0),
	  step_(1),
	  throwingCounter_(0)
      {
	// Nothing to do
      }

      /* Virtual constructor */
      Compact * Compact::clone() const
      {
	return new Compact(*this);
      }

      /* Store the point according to the strategy */
      void Compact::store(const NumericalPoint & point)
      {
	if (!isInitialized_)
	  {
	    sample_ = NumericalSample(2 * halfMaximumSize_, point.getDimension());
	    isInitialized_ = true;
	  }
	// If we don't throw this point
	if (throwingCounter_ == 0)
	  {
	    sample_[index_] = point;
	    ++index_;
	    // Reinitialize the counter
	    throwingCounter_ = step_;
	  }
	// Check if one needs compression
	if (index_ == 2 * halfMaximumSize_)
	  {
	    for (UnsignedLong i = 0; i < halfMaximumSize_; ++i)
	      {
		sample_[i] = sample_[2 * i + 1];
	      }
	    step_ *= 2;
	    throwingCounter_ = step_;
	    index_ = halfMaximumSize_;
	  }
	--throwingCounter_;
      }

      /* Sample accessor */
      NumericalSample Compact::getSample() const
      {
	// If nothing has been stored
	if (!isInitialized_) return sample_;
	NumericalSample outSample(index_, sample_.getDimension());
	for (UnsignedLong i = 0; i < index_; ++i)
	  {
	    // Fill the outSample component-wise in order to avoid memory comsumption due to the creation of Description objects
	    for (UnsignedLong j = 0; j < sample_.getDimension(); ++j)
	      {
		outSample[i][j] = sample_[i][j];
	      }
	  }
	return outSample;
      }

      /* HalfMaximumSize accessor */
      UnsignedLong Compact::getHalfMaximumSize() const
      {
	return halfMaximumSize_;
      }

      /* Index accessor */
      UnsignedLong Compact::getIndex() const
      {
	return index_;
      }

      /* String converter */
      String Compact::str() const
      {
	OSS oss;
	oss << "class=" << Compact::GetClassName();
	return oss;
      }

    } /* namespace Stat */
  } /* namespace Base */
} /* namespace OpenTURNS */
