//                                               -*- C++ -*-
/**
 *  @file  HistoryStrategyImplementation.hxx
 *  @brief This class is a top-level class for the history mechanism of
 *  simulation algorithms. It delegates to its children the effective
 *  history strategy.
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-10-31 11:52:04 +0100 (ven 31 oct 2008) $
 *  Id:      $Id: HistoryStrategyImplementation.hxx 995 2008-10-31 10:52:04Z dutka $
 */
#ifndef OPENTURNS_HISTORYSTRATEGYIMPLEMENTATION_HXX
#define OPENTURNS_HISTORYSTRATEGYIMPLEMENTATION_HXX

#include "PersistentObject.hxx"
#include "NumericalPoint.hxx"
#include "NumericalSample.hxx"

namespace OpenTURNS
{

  namespace Base 
  {

    namespace Stat
    {

      /**
       * @class HistoryStrategyImplementation
       */

      class HistoryStrategyImplementation
	: public Common::PersistentObject
      {

	CLASSNAME;

      public:

	typedef Type::NumericalPoint NumericalPoint;

	/** Constructor with parameters */
	explicit HistoryStrategyImplementation();

	/** Virtual constructor */
	virtual HistoryStrategyImplementation * clone() const;

	/** Store the point according to the strategy */
	virtual void store(const NumericalPoint & point);

	/** Reset the history storage through the isInitialized_ flag */
	void reset();

	/** History sample accessor */
	virtual NumericalSample getSample() const;

	/** String converter */
	virtual String str() const;

      protected:
	/** Data container */
	NumericalSample sample_;

	/** Initialization flag */
	Bool isInitialized_;
      } ; /* class HistoryStrategyImplementation */

    } /* namespace Stat */
  } /* namespace Base */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_HISTORYSTRATEGYIMPLEMENTATION_HXX */
