//                                               -*- C++ -*-
/**
 *  @file  NatafEllipticalDistributionHessian.cxx
 *  @brief Class for the Nataf transformation hessian for elliptical
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-10-31 11:52:04 +0100 (ven 31 oct 2008) $
 *  Id:      $Id: NatafEllipticalDistributionHessian.cxx 995 2008-10-31 10:52:04Z dutka $
 */
#include "OT.hxx"
#include "NatafEllipticalDistributionHessian.hxx"
#include "SymmetricTensor.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Algorithm {


      /*
       * @class NatafEllipticalDistributionHessian
       *
       * This class offers an interface for the Nataf function for elliptical distributions
       */

      CLASSNAMEINIT(NatafEllipticalDistributionHessian);

      /* Parameter constructor */
      NatafEllipticalDistributionHessian::NatafEllipticalDistributionHessian(const UnsignedLong dimension):
	ConstantNumericalMathHessianImplementation(OT::Base::Type::SymmetricTensor(dimension, dimension))
      {
	// Nothing to do
      }

      /* Destructor */
      NatafEllipticalDistributionHessian::~NatafEllipticalDistributionHessian()
      {
	// Nothing to do
      }

      /* String converter */
      String NatafEllipticalDistributionHessian::str() const
      {
	return OSS() << "class=" << NatafEllipticalDistributionHessian::GetClassName();
      }

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */
