//                                               -*- C++ -*-
/**
 *  @file  StandardSpaceImportanceSampling.hxx
 *  @brief StandardSpaceImportanceSampling is an implementation of the importance sampling Montex Carlo simulation method
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2007-05-02 14:59:25 +0200 (mer, 02 mai 2007) $
 *  Id:      $Id: StandardSpaceImportanceSampling.hxx 424 2007-05-02 12:59:25Z dutka $
 */
#ifndef OPENTURNS_STANDARDSPACEIMPORTANCESAMPLING_HXX
#define OPENTURNS_STANDARDSPACEIMPORTANCESAMPLING_HXX

#include "StandardSpaceSimulation.hxx"

namespace OpenTURNS
{

  namespace Uncertainty 
  {

    namespace Algorithm
    {

      /**
       * @class StandardSpaceImportanceSampling
       */

      class StandardSpaceImportanceSampling :
	public StandardSpaceSimulation
      {

	CLASSNAME;
      public:

	typedef StandardSpaceSimulation::NumericalSample          NumericalSample;
	typedef StandardSpaceSimulation::InvalidArgumentException InvalidArgumentException;
	typedef StandardSpaceSimulation::StandardEvent            StandardEvent;
	typedef StandardSpaceSimulation::Distribution             Distribution;

	/** Constructor with parameters */
	StandardSpaceImportanceSampling(const AnalyticalResult & AnalyticalResult) throw(InvalidArgumentException);

	/** Virtual constructor */
	virtual StandardSpaceImportanceSampling * clone() const;

	/** String converter */
	String str() const;

      private:

	/** Compute the block sample */
	NumericalSample computeBlockSample();

      } ; /* class StandardSpaceImportanceSampling */

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_STANDARDSPACEIMPORTANCESAMPLING_HXX */
