//                                               -*- C++ -*-
/**
 *  @file  TruncatedNormalFactory.cxx
 *  @brief Factory for TruncatedNormal distribution
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-10-31 11:52:04 +0100 (ven 31 oct 2008) $
 *  Id:      $Id: TruncatedNormalFactory.cxx 995 2008-10-31 10:52:04Z dutka $
 */
#include "TruncatedNormalFactory.hxx"
#include "TruncatedNormal.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Distribution {

      typedef Model::DistributionImplementationFactory::NumericalPoint NumericalPoint;

      /* Default constructor */
      TruncatedNormalFactory::TruncatedNormalFactory()
      {
	// Initialize any other class members here
	// At last, allocate memory space if needed, but go to destructor to free it
      }

      /* Virtual constructor */
      TruncatedNormalFactory * TruncatedNormalFactory::clone() const
      {
	return new TruncatedNormalFactory(*this);
      }


      /* Here is the interface that all derived class must implement */

      TruncatedNormalFactory::DistributionImplementation * TruncatedNormalFactory::buildImplementation(const NumericalSample & sample) const throw(InvalidArgumentException, InternalException)
      {
	if (sample.getSize() == 0) throw InvalidArgumentException(HERE) << "Error: cannot build a TruncatedNormal distribution from an empty sample";
	if (sample.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: can build a TruncatedNormal distribution only from a sample of dimension 1, here dimension=" << sample.getDimension();
	// The method runRFactory checks the ability for R to compute parameters estimates
	const NumericalPoint parametersValue(runRFactory(sample, TruncatedNormal()));
	// Next, we try to build a Weibull distribution, which checks the parameters validity
	try {
	  return TruncatedNormal(parametersValue[0], parametersValue[1], parametersValue[2], parametersValue[3]).clone();
	}
	catch (InvalidArgumentException & ex)
	  {
	    throw InternalException(HERE) << "Error: the estimated parameters values are not valid, mu=" << parametersValue[0] << ", sigma=" << parametersValue[1] << ", a=" << parametersValue[2] << ", b=" << parametersValue[3];
	  }
      }


    } /* namespace Distribution */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */
